@@ -5,12 +5,13 @@
  *	of the Tcl interpreter.
  *
  * Copyright (c) 1987-1994 The Regents of the University of California.
- * Copyright (c) 1994-1996 Sun Microsystems, Inc.
+ * Copyright (c) 1994-1997 Sun Microsystems, Inc.
+ * Copyright (c) 1993-1996 Lucent Technologies.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tcl.h 1.302 97/01/22 08:47:54
+ * SCCS: @(#) tcl.h 1.318 97/06/26 13:43:02
  */
 
 #ifndef _TCL
@@ -36,11 +37,11 @@
 
 #define TCL_MAJOR_VERSION   8
 #define TCL_MINOR_VERSION   0
-#define TCL_RELEASE_LEVEL   0
+#define TCL_RELEASE_LEVEL   1
 #define TCL_RELEASE_SERIAL  2
 
 #define TCL_VERSION	    "8.0"
-#define TCL_PATCH_LEVEL	    "8.0a2"
+#define TCL_PATCH_LEVEL	    "8.0b2"
 
 /*
  * The following definitions set up the proper options for Windows
@@ -197,59 +198,69 @@ typedef long LONG;
 #endif
 
 /*
- * Data structures defined opaquely in this module.  The definitions
- * below just provide dummy types. A few fields are made visible in
- * Tcl_Interp structures, namely those for returning string values.
+ * Data structures defined opaquely in this module. The definitions below
+ * just provide dummy types. A few fields are made visible in Tcl_Interp
+ * structures, namely those used for returning a string result from
+ * commands. Direct access to the result field is discouraged in Tcl 8.0.
+ * The interpreter result is either an object or a string, and the two
+ * values are kept consistent unless some C code sets interp->result
+ * directly. Programmers should use either the procedure Tcl_GetObjResult()
+ * or Tcl_GetStringResult() to read the interpreter's result. See the
+ * SetResult man page for details.
+ * 
  * Note: any change to the Tcl_Interp definition below must be mirrored
- * in the "real" definition in tclInt.h. 
+ * in the "real" definition in tclInt.h.
+ *
  * Note: Tcl_ObjCmdProc procedures do not directly set result and freeProc.
  * Instead, they set a Tcl_Obj member in the "real" structure that can be
  * accessed with Tcl_GetObjResult() and Tcl_SetObjResult().
  */
 
 typedef struct Tcl_Interp {
-    char *result;		/* Points to result string returned by last
-				 * command. */
+    char *result;		/* If the last command returned a string
+				 * result, this points to it. */
     void (*freeProc) _ANSI_ARGS_((char *blockPtr));
-				/* Zero means result is statically allocated.
-				 * TCL_DYNAMIC means result was allocated with
-				 * ckalloc and should be freed with ckfree.
-				 * Other values give address of procedure
-				 * to invoke to free the result.  Must be
-				 * freed by Tcl_Eval before executing next
-				 * command. */
+				/* Zero means the string result is
+				 * statically allocated. TCL_DYNAMIC means
+				 * it was allocated with ckalloc and should
+				 * be freed with ckfree. Other values give
+				 * the address of procedure to invoke to
+				 * free the result. Tcl_Eval must free it
+				 * before executing next command. */
     int errorLine;              /* When TCL_ERROR is returned, this gives
                                  * the line number within the command where
-                                 * the error occurred (1 means first line). */
+                                 * the error occurred (1 if first line). */
 } Tcl_Interp;
 
 typedef struct Tcl_AsyncHandler_ *Tcl_AsyncHandler;
+typedef struct Tcl_Channel_ *Tcl_Channel;
 typedef struct Tcl_Command_ *Tcl_Command;
 typedef struct Tcl_Event Tcl_Event;
-typedef struct Tcl_File_ *Tcl_File;
-typedef struct Tcl_Channel_ *Tcl_Channel;
+typedef struct Tcl_Pid_ *Tcl_Pid;
 typedef struct Tcl_RegExp_ *Tcl_RegExp;
 typedef struct Tcl_TimerToken_ *Tcl_TimerToken;
 typedef struct Tcl_Trace_ *Tcl_Trace;
-typedef struct Tcl_Pid_ *Tcl_Pid;
+typedef struct Tcl_Var_ *Tcl_Var;
 
 /*
- * When a TCL command returns, the string pointer interp->result points to
- * a string containing return information from the command.  In addition,
- * the command procedure returns an integer value, which is one of the
- * following:
+ * When a TCL command returns, the interpreter contains a result from the
+ * command. Programmers are strongly encouraged to use one of the
+ * procedures Tcl_GetObjResult() or Tcl_GetStringResult() to read the
+ * interpreter's result. See the SetResult man page for details. Besides
+ * this result, the command procedure returns an integer code, which is 
+ * one of the following:
  *
- * TCL_OK		Command completed normally;  interp->result contains
- *			the command's result.
+ * TCL_OK		Command completed normally; the interpreter's
+ *			result contains	the command's result.
  * TCL_ERROR		The command couldn't be completed successfully;
- *			interp->result describes what went wrong.
+ *			the interpreter's result describes what went wrong.
  * TCL_RETURN		The command requests that the current procedure
- *			return;  interp->result contains the procedure's
- *			return value.
+ *			return; the interpreter's result contains the
+ *			procedure's return value.
  * TCL_BREAK		The command requests that the innermost loop
- *			be exited;  interp->result is meaningless.
+ *			be exited; the interpreter's result is meaningless.
  * TCL_CONTINUE		Go on to the next iteration of the current loop;
- *			interp->result is meaningless.
+ *			the interpreter's result is meaningless.
  */
 
 #define TCL_OK		0
@@ -314,8 +325,9 @@ typedef void (Tcl_InterpDeleteProc) _ANSI_ARGS_((ClientData clientData,
 	Tcl_Interp *interp));
 typedef int (Tcl_MathProc) _ANSI_ARGS_((ClientData clientData,
 	Tcl_Interp *interp, Tcl_Value *args, Tcl_Value *resultPtr));
+typedef void (Tcl_NamespaceDeleteProc) _ANSI_ARGS_((ClientData clientData));
 typedef int (Tcl_ObjCmdProc) _ANSI_ARGS_((ClientData clientData,
-	Tcl_Interp *interp, int objc, struct Tcl_Obj *objv[]));
+	Tcl_Interp *interp, int objc, struct Tcl_Obj * CONST objv[]));
 typedef int (Tcl_PackageInitProc) _ANSI_ARGS_((Tcl_Interp *interp));
 typedef void (Tcl_TcpAcceptProc) _ANSI_ARGS_((ClientData callbackData,
         Tcl_Channel chan, char *address, int port));
@@ -353,37 +365,31 @@ typedef struct Tcl_ObjType {
 
 /*
  * One of the following structures exists for each object in the Tcl
- * system.  An object stores a value as either a string, some internal
+ * system. An object stores a value as either a string, some internal
  * representation, or both.
  */
 
 typedef struct Tcl_Obj {
     int refCount;		/* When 0 the object will be freed. */
     char *bytes;		/* This points to the first byte of the
-				 * object's string representation. The
-				 * array must be followed by a null byte
-				 * (i.e., at offset length) but may also
-				 * contain embedded null characters. The
-				 * array's storage is allocated by
-				 * ckalloc. NULL indicates the string
-				 * rep is empty or invalid and must be
-				 * regenerated from the internal rep.
-				 * Clients should use
-				 * Tcl_GetStringFromObj to get a pointer
-				 * to the byte array as a readonly
-				 * value. As a special case, if both
-				 * bytes and typePtr are NULL, the
-				 * object represents an empty string. */
+				 * object's string representation. The array
+				 * must be followed by a null byte (i.e., at
+				 * offset length) but may also contain
+				 * embedded null characters. The array's
+				 * storage is allocated by ckalloc. NULL
+				 * means the string rep is invalid and must
+				 * be regenerated from the internal rep.
+				 * Clients should use Tcl_GetStringFromObj
+				 * to get a pointer to the byte array as a
+				 * readonly value. */
     int length;			/* The number of bytes at *bytes, not
 				 * including the terminating null. */
     Tcl_ObjType *typePtr;	/* Denotes the object's type. Always
 				 * corresponds to the type of the object's
 				 * internal rep. NULL indicates the object
-				 * has no internal rep (has no type). If
-				 * both string and typePtr are NULL, the
-				 * Tcl_Obj represents an empty string. */
+				 * has no internal rep (has no type). */
     union {			/* The internal representation: */
-	long intValue;		/*   - an integer value */
+	long longValue;		/*   - an long integer value */
 	double doubleValue;	/*   - a double-precision floating value */
 	VOID *otherValuePtr;	/*   - another, type-specific value */
 	struct {		/*   - internal rep as two pointers */
@@ -419,9 +425,10 @@ typedef struct Tcl_Obj {
 
 EXTERN Tcl_Obj *	Tcl_NewBooleanObj _ANSI_ARGS_((int boolValue));
 EXTERN Tcl_Obj *	Tcl_NewDoubleObj _ANSI_ARGS_((double doubleValue));
-EXTERN Tcl_Obj *	Tcl_NewIntObj _ANSI_ARGS_((long intValue));
+EXTERN Tcl_Obj *	Tcl_NewIntObj _ANSI_ARGS_((int intValue));
 EXTERN Tcl_Obj *	Tcl_NewListObj _ANSI_ARGS_((int objc,
-			    Tcl_Obj **objv));
+			    Tcl_Obj *CONST objv[]));
+EXTERN Tcl_Obj *	Tcl_NewLongObj _ANSI_ARGS_((long longValue));
 EXTERN Tcl_Obj *	Tcl_NewObj _ANSI_ARGS_((void));
 EXTERN Tcl_Obj *	Tcl_NewStringObj _ANSI_ARGS_((char *bytes,
 			    int length));
@@ -432,9 +439,11 @@ EXTERN Tcl_Obj *	Tcl_NewStringObj _ANSI_ARGS_((char *bytes,
 #  define Tcl_NewDoubleObj(val) \
      Tcl_DbNewDoubleObj(val, __FILE__, __LINE__)
 #  define Tcl_NewIntObj(val) \
-     Tcl_DbNewIntObj(val, __FILE__, __LINE__)
+     Tcl_DbNewLongObj(val, __FILE__, __LINE__)
 #  define Tcl_NewListObj(objc, objv) \
      Tcl_DbNewListObj(objc, objv, __FILE__, __LINE__)
+#  define Tcl_NewLongObj(val) \
+     Tcl_DbNewLongObj(val, __FILE__, __LINE__)
 #  define Tcl_NewObj() \
      Tcl_DbNewObj(__FILE__, __LINE__)
 #  define Tcl_NewStringObj(bytes, len) \
@@ -442,26 +451,98 @@ EXTERN Tcl_Obj *	Tcl_NewStringObj _ANSI_ARGS_((char *bytes,
 #endif /* TCL_MEM_DEBUG */
 
 /*
- * Information about commands that is returned by Tcl_GetCmdInfo and passed
- * to Tcl_SetCmdInfo. proc is a traditional Tcl argc/argv string-based
- * command procedure while objProc is an objc/objv object-based procedure.
- * objProc is called directly by the bytecode interpreter whenever the
- * command is invoked. proc is only called by the compatibility routine
- * TclInvokeStringCommand when no object-based procedure was otherwise
- * defined for a command. Tcl_CreateCommand and Tcl_CreateObjCommand
- * ensure that both proc and objProc are non-NULL. 
+ * The following definitions support Tcl's namespace facility.
+ * Note: the first five fields must match exactly the fields in a
+ * Namespace structure (see tcl.h). 
  */
 
+typedef struct Tcl_Namespace {
+    char *name;                 /* The namespace's name within its parent
+				 * namespace. This contains no ::'s. The
+				 * name of the global namespace is ""
+				 * although "::" is an synonym. */
+    char *fullName;             /* The namespace's fully qualified name.
+				 * This starts with ::. */
+    ClientData clientData;      /* Arbitrary value associated with this
+				 * namespace. */
+    Tcl_NamespaceDeleteProc* deleteProc;
+                                /* Procedure invoked when deleting the
+				 * namespace to, e.g., free clientData. */
+    struct Tcl_Namespace* parentPtr;
+                                /* Points to the namespace that contains
+				 * this one. NULL if this is the global
+				 * namespace. */
+} Tcl_Namespace;
+
+/*
+ * The following structure represents a call frame, or activation record.
+ * A call frame defines a naming context for a procedure call: its local
+ * scope (for local variables) and its namespace scope (used for non-local
+ * variables; often the global :: namespace). A call frame can also define
+ * the naming context for a namespace eval or namespace inscope command:
+ * the namespace in which the command's code should execute. The
+ * Tcl_CallFrame structures exist only while procedures or namespace
+ * eval/inscope's are being executed, and provide a Tcl call stack.
+ * 
+ * A call frame is initialized and pushed using Tcl_PushCallFrame and
+ * popped using Tcl_PopCallFrame. Storage for a Tcl_CallFrame must be
+ * provided by the Tcl_PushCallFrame caller, and callers typically allocate
+ * them on the C call stack for efficiency. For this reason, Tcl_CallFrame
+ * is defined as a structure and not as an opaque token. However, most
+ * Tcl_CallFrame fields are hidden since applications should not access
+ * them directly; others are declared as "dummyX".
+ *
+ * WARNING!! The structure definition must be kept consistent with the
+ * CallFrame structure in tclInt.h. If you change one, change the other.
+ */
+
+typedef struct Tcl_CallFrame {
+    Tcl_Namespace *nsPtr;
+    int dummy1;
+    int dummy2;
+    char *dummy3;
+    char *dummy4;
+    char *dummy5;
+    int dummy6;
+    char *dummy7;
+    char *dummy8;
+    int dummy9;
+    char* dummy10;
+} Tcl_CallFrame;
+
+/*
+ * Information about commands that is returned by Tcl_GetCmdInfo and passed
+ * to Tcl_SetCmdInfo. objProc is an objc/objv object-based command procedure
+ * while proc is a traditional Tcl argc/argv string-based procedure.
+ * Tcl_CreateObjCommand and Tcl_CreateCommand ensure that both objProc and
+ * proc are non-NULL and can be called to execute the command. However,
+ * it may be faster to call one instead of the other. The member
+ * isNativeObjectProc is set to 1 if an object-based procedure was
+ * registered by Tcl_CreateObjCommand, and to 0 if a string-based procedure
+ * was registered by Tcl_CreateCommand. The other procedure is typically set
+ * to a compatibility wrapper that does string-to-object or object-to-string
+ * argument conversions then calls the other procedure.
+ */
+     
 typedef struct Tcl_CmdInfo {
-    Tcl_CmdProc *proc;		/* Command's string-based procedure. */
-    Tcl_ObjCmdProc *objProc;	/* Command's object-based procedure. */
-    ClientData clientData;	/* ClientData for string proc. */
-    ClientData objClientData;	/* ClientData for object proc. */
+    int isNativeObjectProc;	 /* 1 if objProc was registered by a call to
+				  * Tcl_CreateObjCommand; 0 otherwise.
+				  * Tcl_SetCmdInfo does not modify this
+				  * field. */
+    Tcl_ObjCmdProc *objProc;	 /* Command's object-based procedure. */
+    ClientData objClientData;	 /* ClientData for object proc. */
+    Tcl_CmdProc *proc;		 /* Command's string-based procedure. */
+    ClientData clientData;	 /* ClientData for string proc. */
     Tcl_CmdDeleteProc *deleteProc;
-                                /* Procedure to call when command is
-                                 * deleted. */
-    ClientData deleteData;	/* Value to pass to deleteProc (usually
-				 * the same as clientData). */
+                                 /* Procedure to call when command is
+                                  * deleted. */
+    ClientData deleteData;	 /* Value to pass to deleteProc (usually
+				  * the same as clientData). */
+    Tcl_Namespace *namespacePtr; /* Points to the namespace that contains
+				  * this command. Note that Tcl_SetCmdInfo
+				  * will not change a command's namespace;
+				  * use Tcl_RenameCommand to do that. */
+
 } Tcl_CmdInfo;
 
 /*
@@ -473,7 +554,7 @@ typedef struct Tcl_CmdInfo {
 #define TCL_DSTRING_STATIC_SIZE 200
 typedef struct Tcl_DString {
     char *string;		/* Points to beginning of string:  either
-				 * staticSpace below or a malloc'ed array. */
+				 * staticSpace below or a malloced array. */
     int length;			/* Number of non-NULL characters in the
 				 * string. */
     int spaceAvl;		/* Total number of bytes available for the
@@ -504,6 +585,13 @@ typedef struct Tcl_DString {
 
 #define TCL_DONT_USE_BRACES	1
 
+/*
+ * Flag that may be passed to Tcl_GetIndexFromObj to force it to disallow
+ * abbreviated strings.
+ */
+
+#define TCL_EXACT	1
+
 /*
  * Flag values passed to Tcl_RecordAndEval.
  * WARNING: these bit choices must not conflict with the bit choices
@@ -526,16 +614,17 @@ typedef struct Tcl_DString {
  * Flag values passed to variable-related procedures.
  */
 
-#define TCL_GLOBAL_ONLY		1
-#define TCL_APPEND_VALUE	2
-#define TCL_LIST_ELEMENT	4
-#define TCL_TRACE_READS		0x10
-#define TCL_TRACE_WRITES	0x20
-#define TCL_TRACE_UNSETS	0x40
-#define TCL_TRACE_DESTROYED	0x80
-#define TCL_INTERP_DESTROYED	0x100
-#define TCL_LEAVE_ERR_MSG	0x200
-#define TCL_PART1_NOT_PARSED	0x400
+#define TCL_GLOBAL_ONLY		 1
+#define TCL_NAMESPACE_ONLY	 2
+#define TCL_APPEND_VALUE	 4
+#define TCL_LIST_ELEMENT	 8
+#define TCL_TRACE_READS		 0x10
+#define TCL_TRACE_WRITES	 0x20
+#define TCL_TRACE_UNSETS	 0x40
+#define TCL_TRACE_DESTROYED	 0x80
+#define TCL_INTERP_DESTROYED	 0x100
+#define TCL_LEAVE_ERR_MSG	 0x200
+#define TCL_PARSE_PART1		 0x400
 
 /*
  * Types for linked variables:
@@ -587,21 +676,6 @@ EXTERN void		Tcl_ValidateAllMemory _ANSI_ARGS_((char *file,
 
 #endif /* TCL_MEM_DEBUG */
 
-/*
- * Macros to free up result of interpreter.
- */
-
-#define Tcl_FreeResult(interp)					\
-    if ((interp)->freeProc != 0) {				\
-	if (((interp)->freeProc == TCL_DYNAMIC)			\
-	    || ((interp)->freeProc == (Tcl_FreeProc *) free)) {	\
-	    ckfree((interp)->result);				\
-	} else {						\
-	    (*(interp)->freeProc)((interp)->result);		\
-	}							\
-	(interp)->freeProc = 0;					\
-    }
-
 /*
  * Forward declaration of Tcl_HashTable.  Needed by some C++ compilers
  * to prevent errors when the forward reference to Tcl_HashTable is
@@ -745,13 +819,21 @@ struct Tcl_Event {
 };
 
 /*
- * Positions to pass to Tk_QueueEvent:
+ * Positions to pass to Tcl_QueueEvent:
  */
 
 typedef enum {
     TCL_QUEUE_TAIL, TCL_QUEUE_HEAD, TCL_QUEUE_MARK
 } Tcl_QueuePosition;
 
+/*
+ * Values to pass to Tcl_SetServiceMode to specify the behavior of notifier
+ * event routines.
+ */
+
+#define TCL_SERVICE_NONE 0
+#define TCL_SERVICE_ALL 1
+
 /*
  * The following structure keeps is used to hold a time value, either as
  * an absolute time (the number of seconds from the epoch) or as an
@@ -788,28 +870,27 @@ typedef struct Tcl_Time {
  * Typedefs for the various operations in a channel type:
  */
 
-typedef int	(Tcl_DriverBlockModeProc) _ANSI_ARGS_((ClientData instanceData,
-		    int mode));
+typedef int	(Tcl_DriverBlockModeProc) _ANSI_ARGS_((
+		    ClientData instanceData, int mode));
 typedef int	(Tcl_DriverCloseProc) _ANSI_ARGS_((ClientData instanceData,
 		    Tcl_Interp *interp));
 typedef int	(Tcl_DriverInputProc) _ANSI_ARGS_((ClientData instanceData,
 		    char *buf, int toRead, int *errorCodePtr));
 typedef int	(Tcl_DriverOutputProc) _ANSI_ARGS_((ClientData instanceData,
-	            char *buf, int toWrite, int *errorCodePtr));
+		    char *buf, int toWrite, int *errorCodePtr));
 typedef int	(Tcl_DriverSeekProc) _ANSI_ARGS_((ClientData instanceData,
 		    long offset, int mode, int *errorCodePtr));
 typedef int	(Tcl_DriverSetOptionProc) _ANSI_ARGS_((
 		    ClientData instanceData, Tcl_Interp *interp,
-                    char *optionName, char *value));
+	            char *optionName, char *value));
 typedef int	(Tcl_DriverGetOptionProc) _ANSI_ARGS_((
-		    ClientData instanceData, char *optionName,
-                    Tcl_DString *dsPtr));
-typedef void	(Tcl_DriverWatchChannelProc) _ANSI_ARGS_((
-    		    ClientData instanceData, int mask));
-typedef int	(Tcl_DriverChannelReadyProc) _ANSI_ARGS_((
-    		    ClientData instanceData, int mask));
-typedef Tcl_File (Tcl_DriverGetFileProc) _ANSI_ARGS_((ClientData instanceData,
-		    int mask));
+		    ClientData instanceData, Tcl_Interp *interp,
+		    char *optionName, Tcl_DString *dsPtr));
+typedef void	(Tcl_DriverWatchProc) _ANSI_ARGS_((
+		    ClientData instanceData, int mask));
+typedef int	(Tcl_DriverGetHandleProc) _ANSI_ARGS_((
+		    ClientData instanceData, int direction,
+		    ClientData *handlePtr));
 
 /*
  * Enum for different end of line translation and recognition modes.
@@ -823,6 +904,9 @@ typedef enum Tcl_EolTranslation {
 } Tcl_EolTranslation;
 
 /*
+ * Andreas Kupries <a.kupries@westend.com>, 05/31/1997.
+ * Support of Tcl-Trf (binio).
+ *
  * Enum for different byteorders.
  */
 
@@ -858,13 +942,10 @@ typedef struct Tcl_ChannelType {
     					/* Set an option on a channel. */
     Tcl_DriverGetOptionProc *getOptionProc;
     					/* Get an option from a channel. */
-    Tcl_DriverWatchChannelProc *watchChannelProc;
-    					/* Set up the notifier to watch
+    Tcl_DriverWatchProc *watchProc;	/* Set up the notifier to watch
                                          * for events on this channel. */
-    Tcl_DriverChannelReadyProc *channelReadyProc;
-    					/* Check for events of interest on
-                                         * this channel. */
-    Tcl_DriverGetFileProc *getFileProc;	/* Get a Tcl_File from the channel
+    Tcl_DriverGetHandleProc *getHandleProc;
+					/* Get an OS handle from the channel
                                          * or NULL if not supported. */
 } Tcl_ChannelType;
 
@@ -878,19 +959,6 @@ typedef struct Tcl_ChannelType {
 #define TCL_MODE_NONBLOCKING 1		/* Put channel into nonblocking
 					 * mode. */
 
-/*
- * Types for file handles:
- */
-
-#define TCL_UNIX_FD	1
-#define TCL_MAC_FILE	2
-#define TCL_MAC_SOCKET	3
-#define TCL_WIN_PIPE	4
-#define TCL_WIN_FILE	5
-#define TCL_WIN_SOCKET	6
-#define TCL_WIN_CONSOLE 7
-#define TCL_WIN32S_PIPE	8
-
 /*
  * Enum for different types of file paths.
  */
@@ -901,17 +969,6 @@ typedef enum Tcl_PathType {
     TCL_PATH_VOLUME_RELATIVE
 } Tcl_PathType;
 
-/*
- * The following interface is exported for backwards compatibility, but
- * is only implemented on Unix.  Portable applications should use
- * Tcl_OpenCommandChannel, instead.
- */
-
-EXTERN int		Tcl_CreatePipeline _ANSI_ARGS_((Tcl_Interp *interp,
-			    int argc, char **argv, Tcl_Pid **pidArrayPtr,
-			    int *inPipePtr, int *outPipePtr,
-			    int *errFilePtr));
-
 /*
  * Exported Tcl procedures:
  */
@@ -921,10 +978,16 @@ EXTERN void		Tcl_AddErrorInfo _ANSI_ARGS_((Tcl_Interp *interp,
 EXTERN void		Tcl_AddObjErrorInfo _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *message, int length));
 EXTERN void		Tcl_AllowExceptions _ANSI_ARGS_((Tcl_Interp *interp));
+EXTERN int		Tcl_AppendAllObjTypes _ANSI_ARGS_((
+			    Tcl_Interp *interp, Tcl_Obj *objPtr));
 EXTERN void		Tcl_AppendElement _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string));
 EXTERN void		Tcl_AppendResult _ANSI_ARGS_(
-    			    TCL_VARARGS(Tcl_Interp *,interp));
+			    TCL_VARARGS(Tcl_Interp *,interp));
+EXTERN void		Tcl_AppendToObj _ANSI_ARGS_((Tcl_Obj *objPtr,
+			    char *bytes, int length));
+EXTERN void		Tcl_AppendStringsToObj _ANSI_ARGS_(
+			    TCL_VARARGS(Tcl_Obj *,interp));
 EXTERN int		Tcl_AppInit _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN Tcl_AsyncHandler	Tcl_AsyncCreate _ANSI_ARGS_((Tcl_AsyncProc *proc,
 			    ClientData clientData));
@@ -936,6 +999,8 @@ EXTERN int		Tcl_AsyncReady _ANSI_ARGS_((void));
 EXTERN void		Tcl_BackgroundError _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN char		Tcl_Backslash _ANSI_ARGS_((char *src,
 			    int *readPtr));
+EXTERN int		Tcl_BadChannelOption _ANSI_ARGS_((Tcl_Interp *interp,
+			    char *optionName, char *optionList));
 EXTERN void		Tcl_CallWhenDeleted _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_InterpDeleteProc *proc,
 			    ClientData clientData));
@@ -948,6 +1013,10 @@ EXTERN int		Tcl_Close _ANSI_ARGS_((Tcl_Interp *interp,
         		    Tcl_Channel chan));
 EXTERN int		Tcl_CommandComplete _ANSI_ARGS_((char *cmd));
 EXTERN char *		Tcl_Concat _ANSI_ARGS_((int argc, char **argv));
+EXTERN Tcl_Obj *	Tcl_ConcatObj _ANSI_ARGS_((int objc,
+			    Tcl_Obj *CONST objv[]));
+EXTERN int		Tcl_ConvertCountedElement _ANSI_ARGS_((char *src,
+			    int length, char *dst, int flags));
 EXTERN int		Tcl_ConvertElement _ANSI_ARGS_((char *src,
 			    char *dst, int flags));
 EXTERN int		Tcl_ConvertToType _ANSI_ARGS_((Tcl_Interp *interp,
@@ -955,6 +1024,10 @@ EXTERN int		Tcl_ConvertToType _ANSI_ARGS_((Tcl_Interp *interp,
 EXTERN int		Tcl_CreateAlias _ANSI_ARGS_((Tcl_Interp *slave,
 			    char *slaveCmd, Tcl_Interp *target,
         		    char *targetCmd, int argc, char **argv));
+EXTERN int		Tcl_CreateAliasObj _ANSI_ARGS_((Tcl_Interp *slave,
+			    char *slaveCmd, Tcl_Interp *target,
+        		    char *targetCmd, int objc,
+		            Tcl_Obj *CONST objv[]));
 EXTERN Tcl_Channel	Tcl_CreateChannel _ANSI_ARGS_((
     			    Tcl_ChannelType *typePtr, char *chanName,
                             ClientData instanceData, int mask));
@@ -969,21 +1042,20 @@ EXTERN Tcl_Command	Tcl_CreateCommand _ANSI_ARGS_((Tcl_Interp *interp,
 			    ClientData clientData,
 			    Tcl_CmdDeleteProc *deleteProc));
 EXTERN void		Tcl_CreateEventSource _ANSI_ARGS_((
-			    Tcl_EventSetupProc *setupProc, Tcl_EventCheckProc
-			    *checkProc, ClientData clientData));
+			    Tcl_EventSetupProc *setupProc,
+			    Tcl_EventCheckProc *checkProc,
+			    ClientData clientData));
 EXTERN void		Tcl_CreateExitHandler _ANSI_ARGS_((Tcl_ExitProc *proc,
 			    ClientData clientData));
 EXTERN void		Tcl_CreateFileHandler _ANSI_ARGS_((
-    			    Tcl_File file, int mask, Tcl_FileProc *proc,
+    			    int fd, int mask, Tcl_FileProc *proc,
 			    ClientData clientData));
 EXTERN Tcl_Interp *	Tcl_CreateInterp _ANSI_ARGS_((void));
 EXTERN void		Tcl_CreateMathFunc _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *name, int numArgs, Tcl_ValueType *argTypes,
 			    Tcl_MathProc *proc, ClientData clientData));
-EXTERN void		Tcl_CreateModalTimeout _ANSI_ARGS_((int milliseconds,
-			    Tcl_TimerProc *proc, ClientData clientData));
 EXTERN Tcl_Command	Tcl_CreateObjCommand _ANSI_ARGS_((
-			    Tcl_Interp *interp, char *name, int nameLength,
+			    Tcl_Interp *interp, char *cmdName,
 			    Tcl_ObjCmdProc *proc, ClientData clientData,
 			    Tcl_CmdDeleteProc *deleteProc));
 EXTERN Tcl_Interp *	Tcl_CreateSlave _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1003,10 +1075,10 @@ EXTERN Tcl_Obj *	Tcl_DbNewBooleanObj _ANSI_ARGS_((int boolValue,
                             char *file, int line));
 EXTERN Tcl_Obj *	Tcl_DbNewDoubleObj _ANSI_ARGS_((double doubleValue,
                             char *file, int line));
-EXTERN Tcl_Obj *	Tcl_DbNewIntObj _ANSI_ARGS_((long intValue,
-                            char *file, int line));
 EXTERN Tcl_Obj *	Tcl_DbNewListObj _ANSI_ARGS_((int objc,
-			    Tcl_Obj **objv, char *file, int line));
+			    Tcl_Obj *CONST objv[], char *file, int line));
+EXTERN Tcl_Obj *	Tcl_DbNewLongObj _ANSI_ARGS_((long longValue,
+                            char *file, int line));
 EXTERN Tcl_Obj *	Tcl_DbNewObj _ANSI_ARGS_((char *file, int line));
 EXTERN Tcl_Obj *	Tcl_DbNewStringObj _ANSI_ARGS_((char *bytes,
 			    int length, char *file, int line));
@@ -1014,30 +1086,29 @@ EXTERN void		Tcl_DeleteAssocData _ANSI_ARGS_((Tcl_Interp *interp,
                             char *name));
 EXTERN int		Tcl_DeleteCommand _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *cmdName));
+EXTERN int		Tcl_DeleteCommandFromToken _ANSI_ARGS_((
+			    Tcl_Interp *interp, Tcl_Command command));
 EXTERN void		Tcl_DeleteChannelHandler _ANSI_ARGS_((
     			    Tcl_Channel chan, Tcl_ChannelProc *proc,
                             ClientData clientData));
 EXTERN void		Tcl_DeleteCloseHandler _ANSI_ARGS_((
 			    Tcl_Channel chan, Tcl_CloseProc *proc,
                             ClientData clientData));
+EXTERN void		Tcl_DeleteEvents _ANSI_ARGS_((
+			    Tcl_EventDeleteProc *proc,
+                            ClientData clientData));
 EXTERN void		Tcl_DeleteEventSource _ANSI_ARGS_((
 			    Tcl_EventSetupProc *setupProc,
 			    Tcl_EventCheckProc *checkProc,
 			    ClientData clientData));
-EXTERN void		Tcl_DeleteEvents _ANSI_ARGS_((
-			    Tcl_EventDeleteProc *proc,
-                            ClientData clientData));
-EXTERN void		Tcl_DeleteExitHandler _ANSI_ARGS_((
-			    Tcl_ExitProc *proc, ClientData clientData));
-EXTERN void		Tcl_DeleteFileHandler _ANSI_ARGS_((
-    			    Tcl_File file));
+EXTERN void		Tcl_DeleteExitHandler _ANSI_ARGS_((Tcl_ExitProc *proc,
+			    ClientData clientData));
+EXTERN void		Tcl_DeleteFileHandler _ANSI_ARGS_((int fd));
 EXTERN void		Tcl_DeleteHashEntry _ANSI_ARGS_((
 			    Tcl_HashEntry *entryPtr));
 EXTERN void		Tcl_DeleteHashTable _ANSI_ARGS_((
 			    Tcl_HashTable *tablePtr));
 EXTERN void		Tcl_DeleteInterp _ANSI_ARGS_((Tcl_Interp *interp));
-EXTERN void		Tcl_DeleteModalTimeout _ANSI_ARGS_((
-			    Tcl_TimerProc *proc, ClientData clientData));
 EXTERN void		Tcl_DeleteTimerHandler _ANSI_ARGS_((
 			    Tcl_TimerToken token));
 EXTERN void		Tcl_DeleteTrace _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1091,27 +1162,26 @@ EXTERN int		Tcl_ExprLong _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, long *ptr));
 EXTERN int		Tcl_ExprLongObj _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_Obj *objPtr, long *ptr));
+EXTERN int		Tcl_ExprObj _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tcl_Obj *objPtr, Tcl_Obj **resultPtrPtr));
 EXTERN int		Tcl_ExprString _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string));
-EXTERN int		Tcl_ExprStringObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tcl_Obj *objPtr));
-EXTERN int		Tcl_FileReady _ANSI_ARGS_((Tcl_File file,
-			    int mask));
 EXTERN void		Tcl_Finalize _ANSI_ARGS_((void));
 EXTERN void		Tcl_FindExecutable _ANSI_ARGS_((char *argv0));
 EXTERN Tcl_HashEntry *	Tcl_FirstHashEntry _ANSI_ARGS_((
 			    Tcl_HashTable *tablePtr,
 			    Tcl_HashSearch *searchPtr));
 EXTERN int		Tcl_Flush _ANSI_ARGS_((Tcl_Channel chan));
-EXTERN void 		Tcl_FreeFile _ANSI_ARGS_((
-    			    Tcl_File file));
 EXTERN void		TclFreeObj _ANSI_ARGS_((Tcl_Obj *objPtr));
+EXTERN void		Tcl_FreeResult _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN int		Tcl_GetAlias _ANSI_ARGS_((Tcl_Interp *interp,
        			    char *slaveCmd, Tcl_Interp **targetInterpPtr,
                             char **targetCmdPtr, int *argcPtr,
 			    char ***argvPtr));
-EXTERN int		Tcl_GetAllObjTypes _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tcl_Obj **objPtrPtr));
+EXTERN int		Tcl_GetAliasObj _ANSI_ARGS_((Tcl_Interp *interp,
+       			    char *slaveCmd, Tcl_Interp **targetInterpPtr,
+                            char **targetCmdPtr, int *objcPtr,
+			    Tcl_Obj ***objv));
 EXTERN ClientData	Tcl_GetAssocData _ANSI_ARGS_((Tcl_Interp *interp,
                             char *name, Tcl_InterpDeleteProc **procPtr));
 EXTERN int		Tcl_GetBoolean _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1123,17 +1193,21 @@ EXTERN Tcl_Channel	Tcl_GetChannel _ANSI_ARGS_((Tcl_Interp *interp,
 	        	    char *chanName, int *modePtr));
 EXTERN int		Tcl_GetChannelBufferSize _ANSI_ARGS_((
     			    Tcl_Channel chan));
+  /* Andreas Kupries <a.kupries@westend.com>, 05/31/1997.
+   * Support of Tcl-Trf (binio).
+   */
 EXTERN Tcl_ByteOrder	Tcl_GetChannelByteorder _ANSI_ARGS_((
     			    Tcl_Channel chan));
-EXTERN Tcl_ByteOrder	Tcl_GetHostByteorder _ANSI_ARGS_(());
-EXTERN Tcl_File		Tcl_GetChannelFile _ANSI_ARGS_((Tcl_Channel chan,
-	        	    int direction));
+EXTERN Tcl_ByteOrder	Tcl_GetHostByteorder _ANSI_ARGS_((void));
+EXTERN int		Tcl_GetChannelHandle _ANSI_ARGS_((Tcl_Channel chan,
+	        	    int direction, ClientData *handlePtr));
 EXTERN ClientData	Tcl_GetChannelInstanceData _ANSI_ARGS_((
     			    Tcl_Channel chan));
 EXTERN int		Tcl_GetChannelMode _ANSI_ARGS_((Tcl_Channel chan));
 EXTERN char *		Tcl_GetChannelName _ANSI_ARGS_((Tcl_Channel chan));
-EXTERN int		Tcl_GetChannelOption _ANSI_ARGS_((Tcl_Channel chan,
-		            char *optionName, Tcl_DString *dsPtr));
+EXTERN int		Tcl_GetChannelOption _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tcl_Channel chan, char *optionName,
+			    Tcl_DString *dsPtr));
 EXTERN Tcl_ChannelType * Tcl_GetChannelType _ANSI_ARGS_((Tcl_Channel chan));
 EXTERN int		Tcl_GetCommandInfo _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *cmdName, Tcl_CmdInfo *infoPtr));
@@ -1147,36 +1221,38 @@ EXTERN int		Tcl_GetDoubleFromObj _ANSI_ARGS_((
 			    double *doublePtr));
 EXTERN int		Tcl_GetErrno _ANSI_ARGS_((void));
 EXTERN int		Tcl_GetErrorLine _ANSI_ARGS_((Tcl_Interp *interp));
-EXTERN Tcl_File		Tcl_GetFile _ANSI_ARGS_((ClientData fileData,
-			    int type));
-EXTERN ClientData	Tcl_GetFileInfo _ANSI_ARGS_((Tcl_File file,
-			    int *typePtr));
 EXTERN char *		Tcl_GetHostName _ANSI_ARGS_((void));
 EXTERN int		Tcl_GetIndexFromObj _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_Obj *objPtr, char **tablePtr, char *msg,
-			    int *indexPtr));
+			    int flags, int *indexPtr));
 EXTERN int		Tcl_GetInt _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, int *intPtr));
 EXTERN int		Tcl_GetInterpPath _ANSI_ARGS_((Tcl_Interp *askInterp,
 			    Tcl_Interp *slaveInterp));
 EXTERN int		Tcl_GetIntFromObj _ANSI_ARGS_((Tcl_Interp *interp,
-			    Tcl_Obj *objPtr, long *intPtr));
+			    Tcl_Obj *objPtr, int *intPtr));
+EXTERN int		Tcl_GetLongFromObj _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tcl_Obj *objPtr, long *longPtr));
 EXTERN Tcl_Interp *	Tcl_GetMaster _ANSI_ARGS_((Tcl_Interp *interp));
-EXTERN ClientData	Tcl_GetNotifierData _ANSI_ARGS_((Tcl_File file,
-			    Tcl_FileFreeProc **freeProcPtr));
 EXTERN Tcl_Obj *	Tcl_GetObjResult _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN Tcl_ObjType *	Tcl_GetObjType _ANSI_ARGS_((char *typeName));
 EXTERN int		Tcl_GetOpenFile _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, int write, int checkUsage,
 			    ClientData *filePtr));
+EXTERN Tcl_Command	Tcl_GetOriginalCommand _ANSI_ARGS_((
+			    Tcl_Command command));
 EXTERN Tcl_PathType	Tcl_GetPathType _ANSI_ARGS_((char *path));
 EXTERN int		Tcl_Gets _ANSI_ARGS_((Tcl_Channel chan,
         		    Tcl_DString *dsPtr));
+EXTERN int		Tcl_GetsObj _ANSI_ARGS_((Tcl_Channel chan,
+        		    Tcl_Obj *objPtr));
+EXTERN int		Tcl_GetServiceMode _ANSI_ARGS_((void));
 EXTERN Tcl_Interp *	Tcl_GetSlave _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *slaveName));
 EXTERN Tcl_Channel	Tcl_GetStdChannel _ANSI_ARGS_((int type));
 EXTERN char *		Tcl_GetStringFromObj _ANSI_ARGS_((Tcl_Obj *objPtr,
 			    int *lengthPtr));
+EXTERN char *		Tcl_GetStringResult _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN char *		Tcl_GetVar _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *varName, int flags));
 EXTERN char *		Tcl_GetVar2 _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1196,6 +1272,8 @@ EXTERN int		Tcl_InputBlocked _ANSI_ARGS_((Tcl_Channel chan));
 EXTERN int		Tcl_InputBuffered _ANSI_ARGS_((Tcl_Channel chan));
 EXTERN int		Tcl_InterpDeleted _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN int		Tcl_IsSafe _ANSI_ARGS_((Tcl_Interp *interp));
+EXTERN void		Tcl_InvalidateStringRep _ANSI_ARGS_((
+			    Tcl_Obj *objPtr));
 EXTERN char *		Tcl_JoinPath _ANSI_ARGS_((int argc, char **argv,
 			    Tcl_DString *resultPtr));
 EXTERN int		Tcl_LinkVar _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1216,17 +1294,19 @@ EXTERN int		Tcl_ListObjLength _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_Obj *listPtr, int *intPtr));
 EXTERN int		Tcl_ListObjReplace _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_Obj *listPtr, int first, int count,
-			    int objc, Tcl_Obj **objv));
+			    int objc, Tcl_Obj *CONST objv[]));
 EXTERN void		Tcl_Main _ANSI_ARGS_((int argc, char **argv,
 			    Tcl_AppInitProc *appInitProc));
-EXTERN Tcl_Channel	Tcl_MakeFileChannel _ANSI_ARGS_((ClientData inFile,
-		            ClientData outFile, int mode));
+EXTERN Tcl_Channel	Tcl_MakeFileChannel _ANSI_ARGS_((ClientData handle,
+			    int mode));
 EXTERN int		Tcl_MakeSafe _ANSI_ARGS_((Tcl_Interp *interp));
 EXTERN Tcl_Channel	Tcl_MakeTcpClientChannel _ANSI_ARGS_((
     			    ClientData tcpSocket));
 EXTERN char *		Tcl_Merge _ANSI_ARGS_((int argc, char **argv));
 EXTERN Tcl_HashEntry *	Tcl_NextHashEntry _ANSI_ARGS_((
 			    Tcl_HashSearch *searchPtr));
+EXTERN void		Tcl_NotifyChannel _ANSI_ARGS_((Tcl_Channel channel,
+			    int mask));
 EXTERN Tcl_Obj *	Tcl_ObjGetVar2 _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_Obj *part1Ptr, Tcl_Obj *part2Ptr,
 			    int flags));
@@ -1277,13 +1357,17 @@ EXTERN void		Tcl_RegisterChannel _ANSI_ARGS_((Tcl_Interp *interp,
 EXTERN void		Tcl_RegisterObjType _ANSI_ARGS_((
 			    Tcl_ObjType *typePtr));
 EXTERN void		Tcl_Release _ANSI_ARGS_((ClientData clientData));
-EXTERN void		Tcl_ResetObjResult _ANSI_ARGS_((Tcl_Interp *interp));
+EXTERN void		Tcl_RestartIdleTimer _ANSI_ARGS_((void));
 EXTERN void		Tcl_ResetResult _ANSI_ARGS_((Tcl_Interp *interp));
 #define Tcl_Return Tcl_SetResult
+EXTERN int		Tcl_ScanCountedElement _ANSI_ARGS_((char *string,
+			    int length, int *flagPtr));
 EXTERN int		Tcl_ScanElement _ANSI_ARGS_((char *string,
 			    int *flagPtr));
 EXTERN int		Tcl_Seek _ANSI_ARGS_((Tcl_Channel chan,
         		    int offset, int mode));
+EXTERN int		Tcl_ServiceAll _ANSI_ARGS_((void));
+EXTERN int		Tcl_ServiceEvent _ANSI_ARGS_((int flags));
 EXTERN void		Tcl_SetAssocData _ANSI_ARGS_((Tcl_Interp *interp,
                             char *name, Tcl_InterpDeleteProc *proc,
                             ClientData clientData));
@@ -1300,12 +1384,18 @@ EXTERN void		Tcl_SetDoubleObj _ANSI_ARGS_((Tcl_Obj *objPtr,
 			    double doubleValue));
 EXTERN void		Tcl_SetErrno _ANSI_ARGS_((int err));
 EXTERN void		Tcl_SetErrorCode _ANSI_ARGS_(
-    			    TCL_VARARGS(Tcl_Interp *,interp));
+    			    TCL_VARARGS(Tcl_Interp *,arg1));
 EXTERN void		Tcl_SetIntObj _ANSI_ARGS_((Tcl_Obj *objPtr, 
-			    long intValue));
+			    int intValue));
+EXTERN void		Tcl_SetListObj _ANSI_ARGS_((Tcl_Obj *objPtr, 
+			    int objc, Tcl_Obj *CONST objv[]));
+EXTERN void		Tcl_SetLongObj _ANSI_ARGS_((Tcl_Obj *objPtr, 
+			    long longValue));
 EXTERN void		Tcl_SetMaxBlockTime _ANSI_ARGS_((Tcl_Time *timePtr));
-EXTERN void		Tcl_SetNotifierData _ANSI_ARGS_((Tcl_File file,
-			    Tcl_FileFreeProc *freeProcPtr, ClientData data));
+EXTERN void		Tcl_SetObjErrorCode _ANSI_ARGS_((Tcl_Interp *interp,
+			    Tcl_Obj *errorObjPtr));
+EXTERN void		Tcl_SetObjLength _ANSI_ARGS_((Tcl_Obj *objPtr,
+			    int length));
 EXTERN void		Tcl_SetObjResult _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_Obj *resultObjPtr));
 EXTERN void		Tcl_SetPanicProc _ANSI_ARGS_((void (*proc)
@@ -1314,10 +1404,12 @@ EXTERN int		Tcl_SetRecursionLimit _ANSI_ARGS_((Tcl_Interp *interp,
 			    int depth));
 EXTERN void		Tcl_SetResult _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *string, Tcl_FreeProc *freeProc));
+EXTERN int		Tcl_SetServiceMode _ANSI_ARGS_((int mode));
 EXTERN void		Tcl_SetStdChannel _ANSI_ARGS_((Tcl_Channel channel,
 			    int type));
 EXTERN void		Tcl_SetStringObj _ANSI_ARGS_((Tcl_Obj *objPtr, 
 			    char *bytes, int length));
+EXTERN void		Tcl_SetTimer _ANSI_ARGS_((Tcl_Time *timePtr));
 EXTERN char *		Tcl_SetVar _ANSI_ARGS_((Tcl_Interp *interp,
 			    char *varName, char *newValue, int flags));
 EXTERN char *		Tcl_SetVar2 _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1336,10 +1428,6 @@ EXTERN void		Tcl_StaticPackage _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tcl_PackageInitProc *safeInitProc));
 EXTERN int		Tcl_StringMatch _ANSI_ARGS_((char *string,
 			    char *pattern));
-EXTERN void		Tcl_StringObjAppend _ANSI_ARGS_((Tcl_Obj *objPtr,
-			    char *bytes, int length));
-EXTERN void		Tcl_StringObjAppendObj _ANSI_ARGS_((Tcl_Obj *objPtr,
-			    Tcl_Obj *srcPtr));
 EXTERN int		Tcl_Tell _ANSI_ARGS_((Tcl_Channel chan));
 #define Tcl_TildeSubst Tcl_TranslateFileName
 EXTERN int		Tcl_TraceVar _ANSI_ARGS_((Tcl_Interp *interp,
@@ -1387,11 +1475,14 @@ EXTERN ClientData	Tcl_VarTraceInfo2 _ANSI_ARGS_((Tcl_Interp *interp,
 EXTERN int		Tcl_WaitForEvent _ANSI_ARGS_((Tcl_Time *timePtr));
 EXTERN Tcl_Pid		Tcl_WaitPid _ANSI_ARGS_((Tcl_Pid pid, int *statPtr, 
 			    int options));
-EXTERN void		Tcl_WatchFile _ANSI_ARGS_((Tcl_File file,
-			    int mask));
 EXTERN int		Tcl_Write _ANSI_ARGS_((Tcl_Channel chan,
-        		    char *s, int slen));
+			    char *s, int slen));
+EXTERN void		Tcl_WrongNumArgs _ANSI_ARGS_((Tcl_Interp *interp,
+			    int objc, Tcl_Obj *CONST objv[], char *message));
 
+/* Andreas Kupries <a.kupries@westend.com>, 05/31/1997.
+ * Support of Tcl-Trf.
+ */
 EXTERN Tcl_Channel      Tcl_ReplaceChannel _ANSI_ARGS_ ((Tcl_Interp* interp,
 			    Tcl_ChannelType* typePtr, ClientData instanceData,
 			    int mask, Tcl_Channel prevChan));
